gedidb.GEDIProcessor
====================

.. currentmodule:: gedidb

.. autoclass:: GEDIProcessor

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~GEDIProcessor.__init__
      ~GEDIProcessor.close
      ~GEDIProcessor.compute
      ~GEDIProcessor.process_single_granule
   
   

   
   
   